summaryrefslogtreecommitdiffstats
path: root/src/configdialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit89c017c3d5126cabd96acce26f538b37b48c085f (patch)
tree115673043b52ffe2e5f8b01ebcd7b886e0a1318b /src/configdialog.h
parent0254ebaa5e056092461fd585b6851d15faa43035 (diff)
downloadtellico-89c017c3d5126cabd96acce26f538b37b48c085f.tar.gz
tellico-89c017c3d5126cabd96acce26f538b37b48c085f.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/tellico@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/configdialog.h')
-rw-r--r--src/configdialog.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/configdialog.h b/src/configdialog.h
index 4bf0fe5..f051857 100644
--- a/src/configdialog.h
+++ b/src/configdialog.h
@@ -53,10 +53,10 @@ public:
/**
* The constructor sets up the Tabbed dialog pages.
*
* @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/
- ConfigDialog(TQWidget* tqparent, const char* name=0);
+ ConfigDialog(TQWidget* parent, const char* name=0);
virtual ~ConfigDialog();
/**
@@ -200,10 +200,10 @@ public:
class SourceListViewItem : public KListViewItem {
public:
- SourceListViewItem(KListView* tqparent, const GeneralFetcherInfo& info,
+ SourceListViewItem(KListView* parent, const GeneralFetcherInfo& info,
const TQString& groupName = TQString());
- SourceListViewItem(KListView* tqparent, TQListViewItem* after,
+ SourceListViewItem(KListView* parent, TQListViewItem* after,
const GeneralFetcherInfo& info, const TQString& groupName = TQString());
void setConfigGroup(const TQString& s) { m_configGroup = s; }
@@ -53,10 +53,10 @@ public:
* The constructor sets up the Tabbed dialog pages.
*
- * @param tqparent A pointer to the tqparent widget
+ * @param parent A pointer to the parent widget
* @param name The widget name
*/